#
# spec file for package ocsync
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ocsync
BuildRequires:  check
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
%if 0%{?suse_version}
BuildRequires:  libiniparser-devel
BuildRequires:  libneon-devel
BuildRequires:  sqlite3-devel
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  libiniparser-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%endif
%if 0%{?fedora_version}
BuildRequires:  iniparser-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
%endif
%if 0%{?mdk_version}
BuildRequires:  iniparser-devel
BuildRequires:  neon-devel
BuildRequires:  sqlite-devel
BuildRequires:  sqlite3-devel
%endif

Version:        0.90.4
Release:        1.1
Summary:        A user level bidirectional client only file synchronizer (owncloud version)
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            http://www.csync.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        baselibs.conf
%if 0%{?sles_version} || 0%{?centos_version} || 0%{?rhel_version}
Patch0:         remove_signal.dif
%endif
%if 0%{?fedora_version} > 16
Patch1:         iniparser_fed17.dif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ocsync is the ownCloud version of csync. csync is an implementation of 
a file synchronizer which provides the feature of roaming home directories 
for Linux clients.

%package -n libocsync0
Summary:        A user level bidirectional client only file synchronizer
Group:          System/Libraries
%if 0%{?suse_version} > 1030
Recommends:     libocsync-plugin-owncloud
%endif

%description -n libocsync0
ocsync is a csync version which is temporarily maintained by the ownCloud
community to support the ownCloud client. csync is an implementation of a 
file synchronizer which provides the feature of roaming home directories 
for Linux clients. csync makes use of libsmbclient in Samba/Windows 
environments.

%package -n libocsync-plugin-owncloud
Summary:        A user level bidirectional client only file synchronizer
Group:          Productivity/Networking/Other
Requires:       libocsync0 = %{version}

%description -n libocsync-plugin-owncloud
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libneon to access ownCloud. 

%package -n libocsync-devel
Summary:        Development files for csync
Group:          Development/Libraries/C and C++
Requires:       libocsync0 = %{version}

%description -n libocsync-devel
The libocsync-devel package contains the static libraries and header
files needed for development with csync.

%package -n libocsync-devel-doc
Summary:        Developer documentation for csync
Group:          Development/Languages/C and C++

%description -n libocsync-devel-doc
The libocsync-devel-doc package provides documentation for csync
development.

%package -n libocsync-doc
Summary:        User documentation for csync
Group:          Development/Languages/C and C++

%description -n libocsync-doc
The libocsync-doc package provides user documentation for csync.

%prep
%setup -q
%if 0%{?sles_version} || 0%{?rhel_version} || 0%{?centos_version}
%patch0 -p 1 
%endif
%if 0%{?fedora_version} > 16
%patch1 -p 1
%endif

%build
if test ! -e "build"; then
  %{__mkdir} build
fi
pushd build
cmake \
  -DCMAKE_C_FLAGS:STRING="%{optflags}" \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DSYSCONF_INSTALL_DIR=%{_sysconfdir} \
%if %{_lib} == lib64
  -DLIB_SUFFIX=64 \
%endif
  %{_builddir}/%{name}-%{version}
%__make %{?jobs:-j%jobs} VERBOSE=1
%__make doc
popd build

%install
pushd build
%if 0%{?suse_version}
%makeinstall
%else
make DESTDIR=%{buildroot} install
%endif
popd build

%post -n libocsync0
/sbin/ldconfig

%postun -n libocsync0
/sbin/ldconfig

%clean
%__rm -rf %{buildroot}

%files
%defattr(-,root,root)
%{_bindir}/ocsync
%{_mandir}/man?/ocsync.*

%files -n libocsync0
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL README
%dir %{_sysconfdir}/ocsync
%config(noreplace) %{_sysconfdir}/ocsync/ocsync.conf
%config(noreplace) %{_sysconfdir}/ocsync/ocsync_exclude.conf
%{_libdir}/libocsync.so.*
%dir %{_libdir}/ocsync-0

%files -n libocsync-plugin-owncloud
%defattr(-,root,root)
%{_libdir}/ocsync-0/ocsync_owncloud.so
%{_libdir}/libhttpbflib.a

%files -n libocsync-devel
%defattr(-,root,root)
%{_includedir}/ocsync
%{_libdir}/libocsync.so

%files -n libocsync-devel-doc
%defattr(-,root,root)
%doc build/doc/html

%files -n libocsync-doc
%defattr(-,root,root)
%{_datadir}/doc/ocsync

%changelog
* Fri Oct 18 2013 freitag@owncloud.com
  version 0.90.4 (released 2013-10-18, ownCloud Client 1.4.2)
  * Count renamed and deleted files for progress information.
  * Do not reset csync internal error state in helper funcs
    and do not overwrite error messages.
    That fixes error reporting to the client.
  * Disable check on inodes on all platforms as inodes are not
    reliable.
  * Fix resuming after user aborting the sync process.
  * enabled HBF debugging permanently.
* Thu Sep 26 2013 freitag@owncloud.com
- removed link file.
* Thu Sep 26 2013 freitag@owncloud.com
- version 0.90.2 (released 2013-09-26, ownCloud Client 1.4.1)
  * Disable comparison of local inode values for the win32 platform,
    workaround for bug #779
  * detect if server does not send an etag after an upload
    completed.
  * fix crash in case of network timeout, reported as
    https://github.com/owncloud/mirall/issues/1010
  * compile and cmake fixes for win32
  * fixed behaviour of csync_exclude
  * documentation and spelling fixes.
* Wed Sep  4 2013 freitag@owncloud.com
- pulled some tweaks from nightly to devel repo.
* Wed Sep  4 2013 danimo@owncloud.com
- updated to 0.90.0
  * Added API to get progress information from csync.
  * Added c_rename function to csync std.
  * Fix: Do renames of files before any puts.
  * Improved database integrity checks.
  * Improvements of database writing efficiendy.
  * Fix: stat file on win32 even if its opened by application.
  * httpbf: configurable block size and threshold.
  * Many fixes found by a Coverity check.
  * Fix: use correct stat struct on all platforms
  * Fix: download resuming.
  * ownCloud module: Bandwith limitation added.
  * Added ability to remove ignored files automatically.
  * Fix: Use int64_t and friends
  * Fix: Removed all compile warnings.
  * Left excluded files and links in csync's tree to be able to show.
    them to the user.
  * Add OC-Total-Length header for better quota handling.
  * Report inbetween progress
* Tue Jun 25 2013 danimo@owncloud.com
- updated to 0.80.0
  * Big file chunking (e.g. up/download of big files)
  * Resuming (download of big files will resume)
  * Fix false conflicts when database is corrupt/missing
  * Fix false conflicts when file is locked
  * Put legitimate conflict files only on client side
  * Fix unreliable sync after push_file failed
  * Fix rename due to inode cast error
  * Make chunking work on nginx setups or through nginx proxies
  * Improve error reporting in csync_update
  * Clean progress database on csync_commit
  * Fix issues detected by Coverity
  * Fix conflict file appearing when a file cannot be stated
  * Do not shadow server errors by not downloading files that have
    failed to download in the past
* Mon Apr 22 2013 danimo@owncloud.com
- update to version 0.70.7
  * [Fixes] Resource exhaustion
  * Better logging of statedb-related errors
* Thu Apr 11 2013 danimo@owncloud.com
- Fix patch for older linux distros
* Thu Apr 11 2013 freitag@owncloud.com
- Adopt remove_signal.dif to current source of ocsync.
* Thu Apr 11 2013 danimo@owncloud.com
- update to version 0.70.6
  * [Fixes] Try to avoid to upload incomplete files
  * [Fixes] Increase read timeout to 300 seconds
  * [Fixes] Handle IGNORE status correctly
  * [Fixes] Set path and phash for ignored files
  * [Fixes] Fix some issues discovered by Coverity
  * [Fixes] Make sure to never allow empty pathes in rmdir
  * [Fixes] Fix a crash caused by superfluous free() calls
* Tue Apr  2 2013 freitag@owncloud.com
- update to version 0.70.5
  * detect 'wrong' conflict files on client side.
  * [Fixes] Give context to module to enable logging (cmd client).
  * [Fixes] Fix version table contents.
  * [Fixes] Fix handling of non statable files on Win32.
  * [Fixes] Fix renames on clientside on read only shares.
  * [Fixes] Various small fixes and improvements.
* Tue Mar  5 2013 freitag@owncloud.com
- Dropped building the sftp and ssh backends for ocsync.
* Tue Feb 26 2013 freitag@owncloud.com
- Now changes in RC phase for ocsync, releasing 0.70.4 for 1.2.1.
* Thu Feb 21 2013 freitag@owncloud.com
- Fixed debian package version.
* Thu Feb 21 2013 freitag@owncloud.com
- Update to version 0.70.4 which is for owncloud client 1.2.1RC1.
* Thu Feb 21 2013 freitag@owncloud.com
- Adopted patch required for iniparser on Fedora platforms.
* Wed Feb 20 2013 freitag@owncloud.com
- copy from :devel to :devel:daily.
* Thu Jan 24 2013 freitag@owncloud.com
- Update to 0.70.3, ocsync version for oCC 1.2.0
  * [Platform] Improved module parameter system.
  * [Platform] New logging framework. Dropped log4c dependency.
  * [Platform] New API to provide sync progress information.
  * [Fixes] More efficiency for the ownCloud plugin through less HTTP requests to
    the server.
  * [Fixes] ownCloud plugin: Improved upload performance.
  * [Fixes] Improved error reporting to mirall.
  * [Fixes] ownCloud plugin: Improved interpretation of HTTP error codes.
  * [Fixes] ownCloud plugin: Do not abort on errors with individual files any
    more.
  * [Fixes] ownCloud plugin: Use renamed session cookie correctly.
  * [Fixes] Lots of other minor fixes.
  * [MacOSX] Use libneon with proper big file support.
  * [Win32] Use libneon with openSSL support now.
* Thu Jan 17 2013 freitag@owncloud.com
- Update to 0.70.1, ocsync version for oCC 1.2.0 beta2
* Fri Dec 21 2012 freitag@owncloud.com
- Update to first beta version of the 1.2.0 release.
* Thu Nov 22 2012 freitag@owncloud.com
- Update to v0.60.2, needed for ownCloud client 1.1.2
  * Migration to cross platform testing system cmocka.
  * Fixed variuos minor things incl. potential mem leaks.
  * Clang fixes.
  * Moved journal database to sync directory.
  * Fixed more csync->ocsync renaming issues.
  * Fixed statedb query below path.
  * Fixed win32 Daylight Saving Time issues.
  * Allow static linking with iniparser and sqlite.
  * Win32: Fix CreateHandle function in local stat.
  * Win32: More wide char fixes.
  * Added version table to journal database.
  * Fixes for HTTP reply computation.
  * Stricter error checks on PROPFIND results.
  * Workaround for DST influenced times from previous versions.
  * Detect looping in mkdirs to fix sharing.
* Thu Oct 18 2012 danimo@owncloud.com 
- Update to v0.60.1, needed for ownCloud client 1.1.1
  * Fix improper memory cleanup which could cause memory leaks
    and crashes
  * Fix memory leak
  * Allow single quote (') in file names
  * Remove stray temporary files
* Wed Oct 10 2012 freitag@owncloud.com
- Update to v0.60.0, needed for ownCloud client 1.1.0
  * simplification of pac based proxy support.
  * Renamed ownCloud version of csync to ocsync for ownCloud.
  * Migration paths for csync database and config.
  * Fixed that exclude patterns are also tested on files basenames.
  * Fixed return type for query function if no database exists.
  * minor code fixes
  * Fixed crash by removing a bogus free.
  * More useful logging.
  * ownCloud: Maintain the http session by handling the HTTP Cookie.
  * Fixed strncpy handling (mkdir on windows problem).
  * extend database with columns uniq id and type.
  * Use server maintained uniq IDs for update detection instead of
    mtimes.
  * Maintain uniq IDs in local database
  * Handle change propagation through the file tree locally and remote.
  * Added module to build a file tree from the local database (dbtree.c)
  * Added methods to query IDs from the server and maintain it locally.
* Fri Oct  5 2012 freitag@owncloud.com
- Update to v0.50.11 Beta
  from now on this package is called ocsync to not confuse with the
  upstream csync.
* Thu Sep 20 2012 freitag@owncloud.com
- Update to v0.50.10 Beta
* Fri Aug 31 2012 msrex@owncloud.com
- Update to v0.50.9 Beta
* Thu Aug 30 2012 msrex@owncloud.com
- Update to v0.50.8:
  * Inode equivalent support for Win32 platforms to support rename
  * ownCloud supports propagates renames from local to webdav MOVE
  * ownCloud module works with proxy, settings from mirall.
  * improved CMake modules (openSSL)
  * Fixed namespace for lastmodified propset.
  * Added cmocka based tests for ownCloud module.
  * Added a config_test.h config header file.
  * Fix link handling: Ignore symlinks.
  * Modules can now report their capabilities to csync core.
  * A lot of minor fixes and improvements.
* Fri Jun 22 2012 freitag@owncloud.com
- update to version 0.50.7 (released 2012-06-19)
  * Added ability to log to a callback, ie. let the app
    catch the log output
  * Added push to remote without pushing to temp file first.
  * Fixed file copy function to use wide character (win32).
  * Fixed loading of statedb if user has special char (win32).
* Wed May 16 2012 freitag@owncloud.com
- update to final 0.50.6
  * Directories with 'strange' characters broke sync. (oC bug #613)
  * Special characters in Windows did not sync correctly. (oC bug #478)
  * Make neon redirecting
  * Switch logging off on Apple to not fill the syslog. (oC bug #622)
* Fri May 11 2012 freitag@owncloud.com
- update to beta of 0.50.6, next release.
* Fri Apr 20 2012 msrex@owncloud.com
- reformat debian packaging files
* Thu Apr 19 2012 msrex@owncloud.com
- clean-up convoluted requires
* Thu Apr 19 2012 msrex@owncloud.com
- also disable sftp module on SLES
* Wed Apr 18 2012 msrex@owncloud.com
- re-enable sftp-module on fedora
* Wed Apr 18 2012 msrex@owncloud.com
- disable sftp-module on RHEL and CentOS
* Wed Apr 18 2012 msrex@owncloud.com
- fix dependencies for RHEL / CentOS
* Wed Apr 18 2012 msrex@owncloud.com
- changes to debian packaging
* Wed Apr 18 2012 freitag@opensuse.org
- version 0.50.5 (released 2012-04-18)
  required for owncloud client 1.0.1
  * removed argp lib dependency
  * simplified and fixed CMake files
  * MacOS porting efforts
  * more granular error reports, thread save
* Mon Apr  2 2012 freitag@opensuse.org
- Update to upstream version 0.50.4 with more fine tunes and fixes.
* Mon Apr  2 2012 freitag@opensuse.org
- Disable sftp for SLES as the package is too old.
* Mon Mar 26 2012 freitag@opensuse.org
- Update to internal beta version 0.50.3 with more bugfixes.
* Tue Mar 13 2012 freitag@opensuse.org
- Update to internal beta version 0.50.2 with more bugfixes.
* Fri Mar  2 2012 freitag@opensuse.org
- Update to internal beta version 0.50.1
* Wed Feb 22 2012 freitag@opensuse.org
- Update to upstream beta version 0.49.9:
  * Added owncloud module.
  * Added backup reconciler.
  * Fixed serveral bugs.
* Tue Feb 16 2010 anschneider@exsuse.de
- Build always with libssh support.
* Mon Feb 15 2010 anschneider@exsuse.de
- Update to version 0.44.0.
  * Migrated sftp module to libssh 0.4.
  * Added more cache entries to the default config.
  * Added missing requirements.
  * Fixed build warnings.
  * Fixed some memory leaks using sftp attributes.
  * Some code cleanups.
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Mon May 25 2009 anschneider@exsuse.de
- Update to version 0.43.0.
  * Added SFTP support with libssh 0.3.
  * Added possibility to pass userdata to the auth function.
  * Added a better version function.
  * Fixed CMake build.
  * Fixed CMake find modules.
  * Fixed some flaws in cstd functions.
  * Documented all public functions.
* Fri Apr 17 2009 anschneider@exsuse.de
- Fix Fedora build.
- Change the way how to set CFLAGS.
* Thu Feb 26 2009 anschneider@suse.de
- Update to version 0.42.0
  * Small fix in the userguide.
* Fri Jan 23 2009 anschneider@suse.de
- Update to version 0.42.0 rc3
  * Added checks for unix extensions.
  * Added more documentation to the userguide.
  * Fixed loading of plugins.
  * Fixed call for deletion functions.
  * Normalize the path to <hostname>/<path> for the statedb filename.
  * More change name of client options to be more descriptive.
- Add recommends for the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Fix loading of plugins.
- Add requires to the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Update to version 0.42.0 rc2
  * Reduced syscalls
  * Fixed a bug in the state database
  * Fixed libsmbclient support
  * Completed userguide
* Fri Dec  5 2008 anschneider@suse.de
- Update to version 0.42.0 rc1
  libcsync:
  * Reduced calls of syscall functions.
  * Added own function to create a temporary filename.
  * Fixed libsmbclient 3.0.x support.
* Wed Sep 10 2008 anschneider@suse.de
- Created a subpackage for each plugin and for the user guide
- Update to version 0.42.0 beta1
  libcsync:
  * Added a sftp module using libssh
  * Added user guide (just a start)
  * Added testcase for update detection
  * Added a function to parse an uri to cstdlib
  * Updated the manpage
  * Fixed some segfaults in cstdlib
  * Fixed some memory leaks
  csync:
  * Improved the auth callback
* Thu Jul  3 2008 anschneider@suse.de
- Set the right group for the different packages
* Wed Jul  2 2008 anschneider@suse.de
- Update to version 0.42.0 alpha4
  libcsync:
  * Added the possibility to run csync completely without a journal
  * Improved chmod calls during propagation. Most of the time we use the
    default mode and don't need to call chmod.
  * Improved the exclude list handling in the file tree walker. This
    increased the speed of the update detection.
  * Fixed csync on PPC
  * Fixed serveral small bugs
  csync:
  * Added commandline option to run csync completely without a journal
* Fri Jun 27 2008 anschneider@suse.de
- Fixed csync on PPC
* Wed Jun 25 2008 anschneider@suse.de
- Update to version 0.42.0 alpha3
  libcsync:
  * Added a tree merger to write a complete journal
  * Added support to run csync without a journal
  * Fixed kerberos support in csync_smb module
  * Fixed closing of files after the copy
  * Fixed update detection to detect special files (fifo, pipes,
    char devices, ..)
  * Fixed O_NOATIME flag on open() if we don't have the permission
  csync:
  * Add a variable to run csync completely without a journal
* Tue Jun 17 2008 anschneider@suse.de
- Fix update detection for special files (fifo, char device, ..)
- Fix propagation for files the user doesn't own
* Mon Jun 16 2008 anschneider@suse.de
- Update to version 0.41.92 (0.42.0 alpha2)
  libcsync:
  * Peformance improvements
  * Add more directories to the standard exclude file
  * Bugfixes
* Wed Jun  4 2008 anschneider@suse.de
- Build for redhat based distributions
* Mon Jun  2 2008 anschneider@suse.de
- Update to version 0.41.91 (0.42.0 alpha1)
* Mon May  5 2008 anschneider@suse.de
- Initial verison 0.41.90
